Metrics
------------------------

.. automodule:: flax.nnx.metrics
.. currentmodule:: flax.nnx.metrics


.. autoclass:: Metric
   :members: __init__, reset, update, compute

.. autoclass:: Average
   :members: __init__, reset, update, compute

.. autoclass:: Accuracy
   :members: update

.. autoclass:: Welford
   :members: __init__, reset, update, compute

.. autoclass:: MultiMetric
   :members: __init__, reset, update, compute

